package com.gct.tools.etlcamelhuge.routeconfig;

import com.alibaba.fastjson.JSONObject;
import org.apache.camel.Exchange;
import org.apache.camel.Message;
import org.apache.camel.Predicate;
import org.apache.camel.Processor;
import org.apache.camel.builder.RouteBuilder;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;

/**
 * class name: CamelJDBCConfiguration
 *
 * @author lloyd
 * @version 1.0
 * @since 2021/4/14 下午3:16
 */
@Configuration
public class CamelJDBCConfiguration extends RouteBuilder{

    /***
     * 从天安那边获取功图数据
     */
    @Override
    public void configure() throws Exception {
        SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
        Date date = new Date(System.currentTimeMillis());
        String formatDate = formatter.format(date)+" 00:00:00";
        // 一小时执行一次
        from("timer:mytimer1?period=3600000")
                .routeId("jdbc-gtsj-?")
                .setHeader("dyna_create_time", constant(formatDate))
                .setBody(simple("select well_id,dyna_create_time,displacement,disp_load from public.pc_fd_pumpjack_dyna_dia_t where dyna_create_time > '${header.dyna_create_time}'::timestamp and dyna_create_time <'${header.dyna_create_time}'::timestamp + '1 day' order by dyna_create_time "))
                .to("jdbc:gtsj")
                .split(body()).process(exchange -> {
            Message in = exchange.getIn();
            HashMap<String, Object> aRow = in.getBody(HashMap.class);
            String prod_date = aRow.get("dyna_create_time").toString().split("\\+")[0];
            aRow.put("dyna_create_time",prod_date);
            if(aRow.get("displacement")!=null && !aRow.get("displacement").equals("") && aRow.get("disp_load")!=null && !aRow.get("disp_load").equals("")){
                String[] displacements = aRow.get("displacement").toString().split(";");
                String[] disp_loads = aRow.get("disp_load").toString().split(";");
                String sgt ="";
                for (int i = 0 ;i<displacements.length;i++){
                    sgt = sgt + displacements[i] +"," + disp_loads[i] +",";
                }
                String[] s = sgt.split(",");
                String w = "";
                for (int i = 0; i < s.length; i++) {
                    w += new BigDecimal(Math.round(Double.parseDouble(s[i]) * 100)).stripTrailingZeros().toPlainString() + ",";
                }
                aRow.put("sgt",w);
            }
        })
                .setBody(simple("update centralbase.cb_temp_well_mech_runtime  set prod_date = '${body[dyna_create_time]}',sgt = '${body[sgt]}'  where well_id = (select well_id  from centralbase.cb_cd_well_source where well_common_name = '${body[well_id]}')"))
                .to("jdbc:centralbase")
                .log("insert!!!").end();

        /***
         * 从天安那边获取状态日数据
         */
        from("timer:mytimer2?period=3600000")
                .routeId("jdbc-ztr-?")
                .setHeader("acqui_time", constant(formatDate))
                .setBody(simple("select well_id,acqui_time,phase_a_current,phase_b_current,phase_c_current,tubing_pre,casing_pre,phase_a_voltage,phase_b_voltage,phase_c_voltage from public.t_dyna_well_oil where acqui_time > '${header.acqui_time}'::timestamp and acqui_time <'${header.acqui_time}'::timestamp + '1 day'"))
                .to("jdbc:gtsj")
                .split(body()).process(exchange -> {
            Message in = exchange.getIn();
            HashMap<String, Object> aRow = in.getBody(HashMap.class);
            if(aRow.get("phase_a_current").toString() == null || aRow.get("phase_b_current").toString() == null ||aRow.get("phase_c_current").toString() == null ||aRow.get("tubing_pre").toString() == null ||aRow.get("casing_pre").toString() == null ||aRow.get("phase_a_voltage").toString() == null ||aRow.get("phase_b_voltage").toString() == null || aRow.get("phase_c_voltage").toString() == null){
                aRow.put("phase_a_current","0.0");
                aRow.put("phase_b_current","0.0");
                aRow.put("phase_c_current","0.0");
                aRow.put("tubing_pre","0.0");
                aRow.put("casing_pre","0.0");
                aRow.put("phase_a_voltage","0.0");
                aRow.put("phase_b_voltage","0.0");
                aRow.put("phase_c_voltage","0.0");
            }
        })
                .setBody(simple("update centralbase.cb_pc_pro_wellbore_status_daily  set prod_date = '${body[acqui_time]}'::timestamp,elec_pump_current_a = '${body[phase_a_current]}',elec_pump_current_b = '${body[phase_b_current]}',elec_pump_current_c = '${body[phase_c_current]}',tubing_pres = '${body[tubing_pre]}',casing_pres = '${body[casing_pre]}' ,elec_pump_voltage_a = '${body[phase_a_voltage]}',elec_pump_voltage_b = '${body[phase_b_voltage]}',elec_pump_voltage_c = '${body[phase_c_voltage]}' where well_id = (select well_id  from centralbase.cb_cd_well_source where well_common_name = '${body[well_id]}')"))
                .to("jdbc:centralbase")
                .log("insert completed")
                .end();

    };


    /*@Bean
    public RouteBuilder routeBuilder() {
        ArrayList<HashMap<String, Object>> hashMaps = new ArrayList<>();
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("timer://foo?period=1000")
                        .routeId("jdbc-pg-?")
                        .setHeader("prod_time_ctl", constant("2021-02-27 10:00:00.000000"))
                        //.setBody(constant("select * from centralbase.cb_temp_well_mech_runtime where prod_date= :prod_time_ctl "))
                        .setBody(simple("select * from centralbase.cb_temp_well_mech_runtime where prod_date= :?prod_time_ctl ::timestamp "))
                        .log("select body :${body}")
                        .to("jdbc:centralbase?useHeadersAsParameters=true")
                        .tracing()
                        //via transform
                        .transform()
                        .body(result -> {
                            ArrayList<HashMap<String, Object>> list = hashMaps.getClass().cast(result);
                            log.info("The data count:{}", list.toString());
                            return list;
                        })
                        //split data to one by one
                        .split(body()).process(exchange -> {
                    Message in = exchange.getIn();
                    HashMap<String, Object> aRow = in.getBody(HashMap.class);
                    log.info("The data count2222:{}", aRow.toString());
                })
                        .log("ok?").setHeader("dddd", constant("ssss"))
                        .process().message(message -> {
                            log.info("message:{}", message.getHeader("dddd"));
                            ArrayList<HashMap<String, Object>>  body = message.getBody(ArrayList.class);
                            log.info("body::::{}",body.toString());
                        })
                        .process(exchange -> {
                            Message in = exchange.getIn();
                            ArrayList<HashMap<String, Object>> aRow = in.getBody(ArrayList.class);
                            log.info("The data count3333:{}", aRow.toString());
                        })
                        //create "insert sql" with parameters
                        .setBody(simple("insert into dgns_gtbaseparam(wellname,recivetime,sgt) values('${body[well_id]}','${body[prod_date]}' :: timestamp,'${body[sgt]}')"))
                        //now for test
                        //.setBody(simple("insert into dgns_gtbaseparam(wellname,recivetime,sgt) values('${body[well_id]}',now(),'${body[sgt]}')"))
                        //look up the insert sql
                        .process().message(message -> {
                    log.info("The insert sql {}", message.getBody(String.class));
                })
                        //try test
                        .doTry()
                        .to("jdbc:diagnosis").log("insert completed")

                        .doCatch(Throwable.class)
                        .log("primary key already exited,insert failed")
                        //"if" statement test
                        *//*.choice()
                            .when(exchange -> {
                                return exchange.getException() != null;
                                if (exchange.getException() != null) {
                                log.error(exchange.getException().getMessage());
                                return exchange.getException().getMessage().contains("already");
                            }
                            return false;
                        }).log("primary key already exited,insert failed")
                        .otherwise().log("insert completed")*//*
                    .endChoice()
                        .end();

            }

            ;


        };
    }*/

    /*@Bean
    public RouteBuilder routeBuilderWithOracle() {
        ArrayList<HashMap<String, Object>> hashMaps = new ArrayList<>();
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("timer://foo?repeatCount=1")
                        .routeId("jdbc-oracle-?")
                        .setHeader("rq", constant("2021-05-10 00:00:00"))
                        //.setBody(constant("select * from centralbase.cb_temp_well_mech_runtime where prod_date= :prod_time_ctl "))
                        .setBody(simple("select * from centralbase.cb_pc_organization where  org_code != 'null' "))
                        .to("jdbc:centralbase")
                        .split(body()).process(exchange -> {
                            Message in = exchange.getIn();
                            HashMap<String, Object> aRow = in.getBody(HashMap.class);
                        }).log("${body}")
                       *//* .setBody(simple("insert into centralbase.cb_cd_well_source(well_id,spud_date) values('${body[JH]}','${body[RQ]}' :: timestamp)"))
                        .to("jdbc:centralbase")
                        .log("insert completed")*//*
                        .end();
            };
        };
    }*/
}
